gzip bug
David L. Morgan
dmorgan@aechelon.com
Tue Oct 31 00:24:00 GMT 2006
Hi All,
I have uncovered a bug in the version of gzip currently shipping with
cygwin (1.3.5-2). I have a binary file that was compressed with gzip 1.3.3
from around 820MB to around 260MB. If I gunzip the file using the default
invocation:
gunzip file.gz
... everything works fine. If I use the stdout invocation:
gunzip -c file.gz > file
... the resulting file differs from the original.
Gunzip does not report any errors. A cursory Google search does not yield any
relevant bug reports or resolutions.
This is on an x86 system running Cygwin 1.5.21-1
Regards,
David Morgan
dmorgan@aechelon.com
--
Unsubscribe info: http://cygwin.com/ml/#unsubscribe-simple
Problem reports: http://cygwin.com/problems.html
Documentation: http://cygwin.com/docs.html
FAQ: http://cygwin.com/faq/
More information about the Cygwin
mailing list